#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FileInfo import FileInfo


class AlipayFincoreComplianceRcsmartContentSubmitModel(object):

    def __init__(self):
        self._app_name = None
        self._app_token = None
        self._biz_code = None
        self._file_info_list = None
        self._request_id = None
        self._scene_code = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_token(self):
        return self._app_token

    @app_token.setter
    def app_token(self, value):
        self._app_token = value
    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def file_info_list(self):
        return self._file_info_list

    @file_info_list.setter
    def file_info_list(self, value):
        if isinstance(value, list):
            self._file_info_list = list()
            for i in value:
                if isinstance(i, FileInfo):
                    self._file_info_list.append(i)
                else:
                    self._file_info_list.append(FileInfo.from_alipay_dict(i))
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_token:
            if hasattr(self.app_token, 'to_alipay_dict'):
                params['app_token'] = self.app_token.to_alipay_dict()
            else:
                params['app_token'] = self.app_token
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.file_info_list:
            if isinstance(self.file_info_list, list):
                for i in range(0, len(self.file_info_list)):
                    element = self.file_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.file_info_list[i] = element.to_alipay_dict()
            if hasattr(self.file_info_list, 'to_alipay_dict'):
                params['file_info_list'] = self.file_info_list.to_alipay_dict()
            else:
                params['file_info_list'] = self.file_info_list
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFincoreComplianceRcsmartContentSubmitModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_token' in d:
            o.app_token = d['app_token']
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'file_info_list' in d:
            o.file_info_list = d['file_info_list']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RefundDescriptionDTO(object):

    def __init__(self):
        self._buyer_amount = None
        self._fail_code = None
        self._kb_order_discount = None
        self._online_payment_no = None
        self._payable_amount = None
        self._payment_id = None
        self._payment_method = None
        self._refund_status = None
        self._seller_amount = None

    @property
    def buyer_amount(self):
        return self._buyer_amount

    @buyer_amount.setter
    def buyer_amount(self, value):
        self._buyer_amount = value
    @property
    def fail_code(self):
        return self._fail_code

    @fail_code.setter
    def fail_code(self, value):
        self._fail_code = value
    @property
    def kb_order_discount(self):
        return self._kb_order_discount

    @kb_order_discount.setter
    def kb_order_discount(self, value):
        self._kb_order_discount = value
    @property
    def online_payment_no(self):
        return self._online_payment_no

    @online_payment_no.setter
    def online_payment_no(self, value):
        self._online_payment_no = value
    @property
    def payable_amount(self):
        return self._payable_amount

    @payable_amount.setter
    def payable_amount(self, value):
        self._payable_amount = value
    @property
    def payment_id(self):
        return self._payment_id

    @payment_id.setter
    def payment_id(self, value):
        self._payment_id = value
    @property
    def payment_method(self):
        return self._payment_method

    @payment_method.setter
    def payment_method(self, value):
        self._payment_method = value
    @property
    def refund_status(self):
        return self._refund_status

    @refund_status.setter
    def refund_status(self, value):
        self._refund_status = value
    @property
    def seller_amount(self):
        return self._seller_amount

    @seller_amount.setter
    def seller_amount(self, value):
        self._seller_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_amount:
            if hasattr(self.buyer_amount, 'to_alipay_dict'):
                params['buyer_amount'] = self.buyer_amount.to_alipay_dict()
            else:
                params['buyer_amount'] = self.buyer_amount
        if self.fail_code:
            if hasattr(self.fail_code, 'to_alipay_dict'):
                params['fail_code'] = self.fail_code.to_alipay_dict()
            else:
                params['fail_code'] = self.fail_code
        if self.kb_order_discount:
            if hasattr(self.kb_order_discount, 'to_alipay_dict'):
                params['kb_order_discount'] = self.kb_order_discount.to_alipay_dict()
            else:
                params['kb_order_discount'] = self.kb_order_discount
        if self.online_payment_no:
            if hasattr(self.online_payment_no, 'to_alipay_dict'):
                params['online_payment_no'] = self.online_payment_no.to_alipay_dict()
            else:
                params['online_payment_no'] = self.online_payment_no
        if self.payable_amount:
            if hasattr(self.payable_amount, 'to_alipay_dict'):
                params['payable_amount'] = self.payable_amount.to_alipay_dict()
            else:
                params['payable_amount'] = self.payable_amount
        if self.payment_id:
            if hasattr(self.payment_id, 'to_alipay_dict'):
                params['payment_id'] = self.payment_id.to_alipay_dict()
            else:
                params['payment_id'] = self.payment_id
        if self.payment_method:
            if hasattr(self.payment_method, 'to_alipay_dict'):
                params['payment_method'] = self.payment_method.to_alipay_dict()
            else:
                params['payment_method'] = self.payment_method
        if self.refund_status:
            if hasattr(self.refund_status, 'to_alipay_dict'):
                params['refund_status'] = self.refund_status.to_alipay_dict()
            else:
                params['refund_status'] = self.refund_status
        if self.seller_amount:
            if hasattr(self.seller_amount, 'to_alipay_dict'):
                params['seller_amount'] = self.seller_amount.to_alipay_dict()
            else:
                params['seller_amount'] = self.seller_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RefundDescriptionDTO()
        if 'buyer_amount' in d:
            o.buyer_amount = d['buyer_amount']
        if 'fail_code' in d:
            o.fail_code = d['fail_code']
        if 'kb_order_discount' in d:
            o.kb_order_discount = d['kb_order_discount']
        if 'online_payment_no' in d:
            o.online_payment_no = d['online_payment_no']
        if 'payable_amount' in d:
            o.payable_amount = d['payable_amount']
        if 'payment_id' in d:
            o.payment_id = d['payment_id']
        if 'payment_method' in d:
            o.payment_method = d['payment_method']
        if 'refund_status' in d:
            o.refund_status = d['refund_status']
        if 'seller_amount' in d:
            o.seller_amount = d['seller_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppPdeductSignAddResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppPdeductSignAddResponse, self).__init__()
        self._agreement_id = None
        self._agreement_status = None
        self._extend_field = None
        self._notify_config = None
        self._out_agreement_id = None
        self._pay_config = None
        self._sign_date = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def agreement_status(self):
        return self._agreement_status

    @agreement_status.setter
    def agreement_status(self, value):
        self._agreement_status = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def notify_config(self):
        return self._notify_config

    @notify_config.setter
    def notify_config(self, value):
        self._notify_config = value
    @property
    def out_agreement_id(self):
        return self._out_agreement_id

    @out_agreement_id.setter
    def out_agreement_id(self, value):
        self._out_agreement_id = value
    @property
    def pay_config(self):
        return self._pay_config

    @pay_config.setter
    def pay_config(self, value):
        if isinstance(value, list):
            self._pay_config = list()
            for i in value:
                self._pay_config.append(i)
    @property
    def sign_date(self):
        return self._sign_date

    @sign_date.setter
    def sign_date(self, value):
        self._sign_date = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppPdeductSignAddResponse, self).parse_response_content(response_content)
        if 'agreement_id' in response:
            self.agreement_id = response['agreement_id']
        if 'agreement_status' in response:
            self.agreement_status = response['agreement_status']
        if 'extend_field' in response:
            self.extend_field = response['extend_field']
        if 'notify_config' in response:
            self.notify_config = response['notify_config']
        if 'out_agreement_id' in response:
            self.out_agreement_id = response['out_agreement_id']
        if 'pay_config' in response:
            self.pay_config = response['pay_config']
        if 'sign_date' in response:
            self.sign_date = response['sign_date']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BrandLevelInfo import BrandLevelInfo
from alipay.aop.api.domain.CategoryLevelInfo import CategoryLevelInfo


class KbExtItemInfo(object):

    def __init__(self):
        self._brand_level_info_list = None
        self._brief = None
        self._category_level_info_list = None
        self._count = None
        self._country = None
        self._currency = None
        self._description = None
        self._goods_id = None
        self._goods_name = None
        self._inner_goods_id = None
        self._item_format = None
        self._pack = None
        self._picture_id_list = None
        self._price = None
        self._specification = None
        self._unit = None

    @property
    def brand_level_info_list(self):
        return self._brand_level_info_list

    @brand_level_info_list.setter
    def brand_level_info_list(self, value):
        if isinstance(value, list):
            self._brand_level_info_list = list()
            for i in value:
                if isinstance(i, BrandLevelInfo):
                    self._brand_level_info_list.append(i)
                else:
                    self._brand_level_info_list.append(BrandLevelInfo.from_alipay_dict(i))
    @property
    def brief(self):
        return self._brief

    @brief.setter
    def brief(self, value):
        self._brief = value
    @property
    def category_level_info_list(self):
        return self._category_level_info_list

    @category_level_info_list.setter
    def category_level_info_list(self, value):
        if isinstance(value, list):
            self._category_level_info_list = list()
            for i in value:
                if isinstance(i, CategoryLevelInfo):
                    self._category_level_info_list.append(i)
                else:
                    self._category_level_info_list.append(CategoryLevelInfo.from_alipay_dict(i))
    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def country(self):
        return self._country

    @country.setter
    def country(self, value):
        self._country = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def inner_goods_id(self):
        return self._inner_goods_id

    @inner_goods_id.setter
    def inner_goods_id(self, value):
        self._inner_goods_id = value
    @property
    def item_format(self):
        return self._item_format

    @item_format.setter
    def item_format(self, value):
        self._item_format = value
    @property
    def pack(self):
        return self._pack

    @pack.setter
    def pack(self, value):
        self._pack = value
    @property
    def picture_id_list(self):
        return self._picture_id_list

    @picture_id_list.setter
    def picture_id_list(self, value):
        if isinstance(value, list):
            self._picture_id_list = list()
            for i in value:
                self._picture_id_list.append(i)
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def specification(self):
        return self._specification

    @specification.setter
    def specification(self, value):
        self._specification = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_level_info_list:
            if isinstance(self.brand_level_info_list, list):
                for i in range(0, len(self.brand_level_info_list)):
                    element = self.brand_level_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.brand_level_info_list[i] = element.to_alipay_dict()
            if hasattr(self.brand_level_info_list, 'to_alipay_dict'):
                params['brand_level_info_list'] = self.brand_level_info_list.to_alipay_dict()
            else:
                params['brand_level_info_list'] = self.brand_level_info_list
        if self.brief:
            if hasattr(self.brief, 'to_alipay_dict'):
                params['brief'] = self.brief.to_alipay_dict()
            else:
                params['brief'] = self.brief
        if self.category_level_info_list:
            if isinstance(self.category_level_info_list, list):
                for i in range(0, len(self.category_level_info_list)):
                    element = self.category_level_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.category_level_info_list[i] = element.to_alipay_dict()
            if hasattr(self.category_level_info_list, 'to_alipay_dict'):
                params['category_level_info_list'] = self.category_level_info_list.to_alipay_dict()
            else:
                params['category_level_info_list'] = self.category_level_info_list
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.country:
            if hasattr(self.country, 'to_alipay_dict'):
                params['country'] = self.country.to_alipay_dict()
            else:
                params['country'] = self.country
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.inner_goods_id:
            if hasattr(self.inner_goods_id, 'to_alipay_dict'):
                params['inner_goods_id'] = self.inner_goods_id.to_alipay_dict()
            else:
                params['inner_goods_id'] = self.inner_goods_id
        if self.item_format:
            if hasattr(self.item_format, 'to_alipay_dict'):
                params['item_format'] = self.item_format.to_alipay_dict()
            else:
                params['item_format'] = self.item_format
        if self.pack:
            if hasattr(self.pack, 'to_alipay_dict'):
                params['pack'] = self.pack.to_alipay_dict()
            else:
                params['pack'] = self.pack
        if self.picture_id_list:
            if isinstance(self.picture_id_list, list):
                for i in range(0, len(self.picture_id_list)):
                    element = self.picture_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.picture_id_list[i] = element.to_alipay_dict()
            if hasattr(self.picture_id_list, 'to_alipay_dict'):
                params['picture_id_list'] = self.picture_id_list.to_alipay_dict()
            else:
                params['picture_id_list'] = self.picture_id_list
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.specification:
            if hasattr(self.specification, 'to_alipay_dict'):
                params['specification'] = self.specification.to_alipay_dict()
            else:
                params['specification'] = self.specification
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbExtItemInfo()
        if 'brand_level_info_list' in d:
            o.brand_level_info_list = d['brand_level_info_list']
        if 'brief' in d:
            o.brief = d['brief']
        if 'category_level_info_list' in d:
            o.category_level_info_list = d['category_level_info_list']
        if 'count' in d:
            o.count = d['count']
        if 'country' in d:
            o.country = d['country']
        if 'currency' in d:
            o.currency = d['currency']
        if 'description' in d:
            o.description = d['description']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'inner_goods_id' in d:
            o.inner_goods_id = d['inner_goods_id']
        if 'item_format' in d:
            o.item_format = d['item_format']
        if 'pack' in d:
            o.pack = d['pack']
        if 'picture_id_list' in d:
            o.picture_id_list = d['picture_id_list']
        if 'price' in d:
            o.price = d['price']
        if 'specification' in d:
            o.specification = d['specification']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceEnterpriseexctrlEmployertitleCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceEnterpriseexctrlEmployertitleCreateResponse, self).__init__()
        self._code = None
        self._msg = None
        self._success = None
        self._title_id = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def title_id(self):
        return self._title_id

    @title_id.setter
    def title_id(self, value):
        self._title_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceEnterpriseexctrlEmployertitleCreateResponse, self).parse_response_content(response_content)
        if 'code' in response:
            self.code = response['code']
        if 'msg' in response:
            self.msg = response['msg']
        if 'success' in response:
            self.success = response['success']
        if 'title_id' in response:
            self.title_id = response['title_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PayerAccountDTO import PayerAccountDTO


class FundPlanDTO(object):

    def __init__(self):
        self._account_id = None
        self._amount = None
        self._calendar_type = None
        self._creator_id = None
        self._date = None
        self._fund_plan_id = None
        self._next_execution = None
        self._payer_account = None
        self._remark = None
        self._status = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def calendar_type(self):
        return self._calendar_type

    @calendar_type.setter
    def calendar_type(self, value):
        self._calendar_type = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def fund_plan_id(self):
        return self._fund_plan_id

    @fund_plan_id.setter
    def fund_plan_id(self, value):
        self._fund_plan_id = value
    @property
    def next_execution(self):
        return self._next_execution

    @next_execution.setter
    def next_execution(self, value):
        self._next_execution = value
    @property
    def payer_account(self):
        return self._payer_account

    @payer_account.setter
    def payer_account(self, value):
        if isinstance(value, PayerAccountDTO):
            self._payer_account = value
        else:
            self._payer_account = PayerAccountDTO.from_alipay_dict(value)
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.calendar_type:
            if hasattr(self.calendar_type, 'to_alipay_dict'):
                params['calendar_type'] = self.calendar_type.to_alipay_dict()
            else:
                params['calendar_type'] = self.calendar_type
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.fund_plan_id:
            if hasattr(self.fund_plan_id, 'to_alipay_dict'):
                params['fund_plan_id'] = self.fund_plan_id.to_alipay_dict()
            else:
                params['fund_plan_id'] = self.fund_plan_id
        if self.next_execution:
            if hasattr(self.next_execution, 'to_alipay_dict'):
                params['next_execution'] = self.next_execution.to_alipay_dict()
            else:
                params['next_execution'] = self.next_execution
        if self.payer_account:
            if hasattr(self.payer_account, 'to_alipay_dict'):
                params['payer_account'] = self.payer_account.to_alipay_dict()
            else:
                params['payer_account'] = self.payer_account
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FundPlanDTO()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'amount' in d:
            o.amount = d['amount']
        if 'calendar_type' in d:
            o.calendar_type = d['calendar_type']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'date' in d:
            o.date = d['date']
        if 'fund_plan_id' in d:
            o.fund_plan_id = d['fund_plan_id']
        if 'next_execution' in d:
            o.next_execution = d['next_execution']
        if 'payer_account' in d:
            o.payer_account = d['payer_account']
        if 'remark' in d:
            o.remark = d['remark']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ProductZoneInfo import ProductZoneInfo


class ProductCategoryInfo(object):

    def __init__(self):
        self._date = None
        self._desc = None
        self._name = None
        self._out_category_id = None
        self._zone_list = None

    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_category_id(self):
        return self._out_category_id

    @out_category_id.setter
    def out_category_id(self, value):
        self._out_category_id = value
    @property
    def zone_list(self):
        return self._zone_list

    @zone_list.setter
    def zone_list(self, value):
        if isinstance(value, list):
            self._zone_list = list()
            for i in value:
                if isinstance(i, ProductZoneInfo):
                    self._zone_list.append(i)
                else:
                    self._zone_list.append(ProductZoneInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_category_id:
            if hasattr(self.out_category_id, 'to_alipay_dict'):
                params['out_category_id'] = self.out_category_id.to_alipay_dict()
            else:
                params['out_category_id'] = self.out_category_id
        if self.zone_list:
            if isinstance(self.zone_list, list):
                for i in range(0, len(self.zone_list)):
                    element = self.zone_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.zone_list[i] = element.to_alipay_dict()
            if hasattr(self.zone_list, 'to_alipay_dict'):
                params['zone_list'] = self.zone_list.to_alipay_dict()
            else:
                params['zone_list'] = self.zone_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ProductCategoryInfo()
        if 'date' in d:
            o.date = d['date']
        if 'desc' in d:
            o.desc = d['desc']
        if 'name' in d:
            o.name = d['name']
        if 'out_category_id' in d:
            o.out_category_id = d['out_category_id']
        if 'zone_list' in d:
            o.zone_list = d['zone_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportEtcInfoModifyModel(object):

    def __init__(self):
        self._biz_agreement_no = None
        self._card_no = None
        self._device_no = None
        self._order_id = None
        self._out_biz_no = None
        self._plate_color = None
        self._plate_no = None
        self._user_id = None
        self._vi_ac = None
        self._vi_gross_mass = None
        self._vi_height = None
        self._vi_length = None
        self._vi_owner_name = None
        self._vi_width = None

    @property
    def biz_agreement_no(self):
        return self._biz_agreement_no

    @biz_agreement_no.setter
    def biz_agreement_no(self, value):
        self._biz_agreement_no = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def device_no(self):
        return self._device_no

    @device_no.setter
    def device_no(self, value):
        self._device_no = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def vi_ac(self):
        return self._vi_ac

    @vi_ac.setter
    def vi_ac(self, value):
        self._vi_ac = value
    @property
    def vi_gross_mass(self):
        return self._vi_gross_mass

    @vi_gross_mass.setter
    def vi_gross_mass(self, value):
        self._vi_gross_mass = value
    @property
    def vi_height(self):
        return self._vi_height

    @vi_height.setter
    def vi_height(self, value):
        self._vi_height = value
    @property
    def vi_length(self):
        return self._vi_length

    @vi_length.setter
    def vi_length(self, value):
        self._vi_length = value
    @property
    def vi_owner_name(self):
        return self._vi_owner_name

    @vi_owner_name.setter
    def vi_owner_name(self, value):
        self._vi_owner_name = value
    @property
    def vi_width(self):
        return self._vi_width

    @vi_width.setter
    def vi_width(self, value):
        self._vi_width = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_agreement_no:
            if hasattr(self.biz_agreement_no, 'to_alipay_dict'):
                params['biz_agreement_no'] = self.biz_agreement_no.to_alipay_dict()
            else:
                params['biz_agreement_no'] = self.biz_agreement_no
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.device_no:
            if hasattr(self.device_no, 'to_alipay_dict'):
                params['device_no'] = self.device_no.to_alipay_dict()
            else:
                params['device_no'] = self.device_no
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.vi_ac:
            if hasattr(self.vi_ac, 'to_alipay_dict'):
                params['vi_ac'] = self.vi_ac.to_alipay_dict()
            else:
                params['vi_ac'] = self.vi_ac
        if self.vi_gross_mass:
            if hasattr(self.vi_gross_mass, 'to_alipay_dict'):
                params['vi_gross_mass'] = self.vi_gross_mass.to_alipay_dict()
            else:
                params['vi_gross_mass'] = self.vi_gross_mass
        if self.vi_height:
            if hasattr(self.vi_height, 'to_alipay_dict'):
                params['vi_height'] = self.vi_height.to_alipay_dict()
            else:
                params['vi_height'] = self.vi_height
        if self.vi_length:
            if hasattr(self.vi_length, 'to_alipay_dict'):
                params['vi_length'] = self.vi_length.to_alipay_dict()
            else:
                params['vi_length'] = self.vi_length
        if self.vi_owner_name:
            if hasattr(self.vi_owner_name, 'to_alipay_dict'):
                params['vi_owner_name'] = self.vi_owner_name.to_alipay_dict()
            else:
                params['vi_owner_name'] = self.vi_owner_name
        if self.vi_width:
            if hasattr(self.vi_width, 'to_alipay_dict'):
                params['vi_width'] = self.vi_width.to_alipay_dict()
            else:
                params['vi_width'] = self.vi_width
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportEtcInfoModifyModel()
        if 'biz_agreement_no' in d:
            o.biz_agreement_no = d['biz_agreement_no']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'device_no' in d:
            o.device_no = d['device_no']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'vi_ac' in d:
            o.vi_ac = d['vi_ac']
        if 'vi_gross_mass' in d:
            o.vi_gross_mass = d['vi_gross_mass']
        if 'vi_height' in d:
            o.vi_height = d['vi_height']
        if 'vi_length' in d:
            o.vi_length = d['vi_length']
        if 'vi_owner_name' in d:
            o.vi_owner_name = d['vi_owner_name']
        if 'vi_width' in d:
            o.vi_width = d['vi_width']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialAntforestPlantConsultModel(object):

    def __init__(self):
        self._account_id = None
        self._apply_type = None
        self._project_id = None
        self._user_id = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def apply_type(self):
        return self._apply_type

    @apply_type.setter
    def apply_type(self, value):
        self._apply_type = value
    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.apply_type:
            if hasattr(self.apply_type, 'to_alipay_dict'):
                params['apply_type'] = self.apply_type.to_alipay_dict()
            else:
                params['apply_type'] = self.apply_type
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialAntforestPlantConsultModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'apply_type' in d:
            o.apply_type = d['apply_type']
        if 'project_id' in d:
            o.project_id = d['project_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPayApplepayTransactionBatchqueryModel(object):

    def __init__(self):
        self._authorization = None
        self._device_identifier = None
        self._provisioning_bundle_identifier = None
        self._tag = None

    @property
    def authorization(self):
        return self._authorization

    @authorization.setter
    def authorization(self, value):
        self._authorization = value
    @property
    def device_identifier(self):
        return self._device_identifier

    @device_identifier.setter
    def device_identifier(self, value):
        self._device_identifier = value
    @property
    def provisioning_bundle_identifier(self):
        return self._provisioning_bundle_identifier

    @provisioning_bundle_identifier.setter
    def provisioning_bundle_identifier(self, value):
        self._provisioning_bundle_identifier = value
    @property
    def tag(self):
        return self._tag

    @tag.setter
    def tag(self, value):
        self._tag = value


    def to_alipay_dict(self):
        params = dict()
        if self.authorization:
            if hasattr(self.authorization, 'to_alipay_dict'):
                params['authorization'] = self.authorization.to_alipay_dict()
            else:
                params['authorization'] = self.authorization
        if self.device_identifier:
            if hasattr(self.device_identifier, 'to_alipay_dict'):
                params['device_identifier'] = self.device_identifier.to_alipay_dict()
            else:
                params['device_identifier'] = self.device_identifier
        if self.provisioning_bundle_identifier:
            if hasattr(self.provisioning_bundle_identifier, 'to_alipay_dict'):
                params['provisioning_bundle_identifier'] = self.provisioning_bundle_identifier.to_alipay_dict()
            else:
                params['provisioning_bundle_identifier'] = self.provisioning_bundle_identifier
        if self.tag:
            if hasattr(self.tag, 'to_alipay_dict'):
                params['tag'] = self.tag.to_alipay_dict()
            else:
                params['tag'] = self.tag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPayApplepayTransactionBatchqueryModel()
        if 'authorization' in d:
            o.authorization = d['authorization']
        if 'device_identifier' in d:
            o.device_identifier = d['device_identifier']
        if 'provisioning_bundle_identifier' in d:
            o.provisioning_bundle_identifier = d['provisioning_bundle_identifier']
        if 'tag' in d:
            o.tag = d['tag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Invoice import Invoice
from alipay.aop.api.domain.WaybillInvoice import WaybillInvoice


class AlipayCommerceLogisticsInvoiceIstdwaybillCreateModel(object):

    def __init__(self):
        self._invoice = None
        self._logistics_code = None
        self._out_invoice_request_no = None
        self._waybill_invoices = None

    @property
    def invoice(self):
        return self._invoice

    @invoice.setter
    def invoice(self, value):
        if isinstance(value, Invoice):
            self._invoice = value
        else:
            self._invoice = Invoice.from_alipay_dict(value)
    @property
    def logistics_code(self):
        return self._logistics_code

    @logistics_code.setter
    def logistics_code(self, value):
        self._logistics_code = value
    @property
    def out_invoice_request_no(self):
        return self._out_invoice_request_no

    @out_invoice_request_no.setter
    def out_invoice_request_no(self, value):
        self._out_invoice_request_no = value
    @property
    def waybill_invoices(self):
        return self._waybill_invoices

    @waybill_invoices.setter
    def waybill_invoices(self, value):
        if isinstance(value, list):
            self._waybill_invoices = list()
            for i in value:
                if isinstance(i, WaybillInvoice):
                    self._waybill_invoices.append(i)
                else:
                    self._waybill_invoices.append(WaybillInvoice.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.invoice:
            if hasattr(self.invoice, 'to_alipay_dict'):
                params['invoice'] = self.invoice.to_alipay_dict()
            else:
                params['invoice'] = self.invoice
        if self.logistics_code:
            if hasattr(self.logistics_code, 'to_alipay_dict'):
                params['logistics_code'] = self.logistics_code.to_alipay_dict()
            else:
                params['logistics_code'] = self.logistics_code
        if self.out_invoice_request_no:
            if hasattr(self.out_invoice_request_no, 'to_alipay_dict'):
                params['out_invoice_request_no'] = self.out_invoice_request_no.to_alipay_dict()
            else:
                params['out_invoice_request_no'] = self.out_invoice_request_no
        if self.waybill_invoices:
            if isinstance(self.waybill_invoices, list):
                for i in range(0, len(self.waybill_invoices)):
                    element = self.waybill_invoices[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.waybill_invoices[i] = element.to_alipay_dict()
            if hasattr(self.waybill_invoices, 'to_alipay_dict'):
                params['waybill_invoices'] = self.waybill_invoices.to_alipay_dict()
            else:
                params['waybill_invoices'] = self.waybill_invoices
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceLogisticsInvoiceIstdwaybillCreateModel()
        if 'invoice' in d:
            o.invoice = d['invoice']
        if 'logistics_code' in d:
            o.logistics_code = d['logistics_code']
        if 'out_invoice_request_no' in d:
            o.out_invoice_request_no = d['out_invoice_request_no']
        if 'waybill_invoices' in d:
            o.waybill_invoices = d['waybill_invoices']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AdvanceOrder import AdvanceOrder


class KoubeiMallScanpurchaseUserpreorderQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMallScanpurchaseUserpreorderQueryResponse, self).__init__()
        self._advance_order = None
        self._buyer_user_id = None
        self._mall_has_card = None
        self._open_card = None
        self._open_card_url = None
        self._order_id = None
        self._status = None

    @property
    def advance_order(self):
        return self._advance_order

    @advance_order.setter
    def advance_order(self, value):
        if isinstance(value, AdvanceOrder):
            self._advance_order = value
        else:
            self._advance_order = AdvanceOrder.from_alipay_dict(value)
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def mall_has_card(self):
        return self._mall_has_card

    @mall_has_card.setter
    def mall_has_card(self, value):
        self._mall_has_card = value
    @property
    def open_card(self):
        return self._open_card

    @open_card.setter
    def open_card(self, value):
        self._open_card = value
    @property
    def open_card_url(self):
        return self._open_card_url

    @open_card_url.setter
    def open_card_url(self, value):
        self._open_card_url = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMallScanpurchaseUserpreorderQueryResponse, self).parse_response_content(response_content)
        if 'advance_order' in response:
            self.advance_order = response['advance_order']
        if 'buyer_user_id' in response:
            self.buyer_user_id = response['buyer_user_id']
        if 'mall_has_card' in response:
            self.mall_has_card = response['mall_has_card']
        if 'open_card' in response:
            self.open_card = response['open_card']
        if 'open_card_url' in response:
            self.open_card_url = response['open_card_url']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.QueryResult import QueryResult


class AlipayEcoMycarCarmodelBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarCarmodelBatchqueryResponse, self).__init__()
        self._query_result = None
        self._query_type = None

    @property
    def query_result(self):
        return self._query_result

    @query_result.setter
    def query_result(self, value):
        if isinstance(value, QueryResult):
            self._query_result = value
        else:
            self._query_result = QueryResult.from_alipay_dict(value)
    @property
    def query_type(self):
        return self._query_type

    @query_type.setter
    def query_type(self, value):
        self._query_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarCarmodelBatchqueryResponse, self).parse_response_content(response_content)
        if 'query_result' in response:
            self.query_result = response['query_result']
        if 'query_type' in response:
            self.query_type = response['query_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CheckResultList import CheckResultList


class KoubeiQualityTestShieldResultSyncModel(object):

    def __init__(self):
        self._batch_no = None
        self._check_result_list = None
        self._order_id = None
        self._out_biz_no = None
        self._partner_id = None
        self._pay_style = None
        self._shop_id = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def check_result_list(self):
        return self._check_result_list

    @check_result_list.setter
    def check_result_list(self, value):
        if isinstance(value, list):
            self._check_result_list = list()
            for i in value:
                if isinstance(i, CheckResultList):
                    self._check_result_list.append(i)
                else:
                    self._check_result_list.append(CheckResultList.from_alipay_dict(i))
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pay_style(self):
        return self._pay_style

    @pay_style.setter
    def pay_style(self, value):
        self._pay_style = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.check_result_list:
            if isinstance(self.check_result_list, list):
                for i in range(0, len(self.check_result_list)):
                    element = self.check_result_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.check_result_list[i] = element.to_alipay_dict()
            if hasattr(self.check_result_list, 'to_alipay_dict'):
                params['check_result_list'] = self.check_result_list.to_alipay_dict()
            else:
                params['check_result_list'] = self.check_result_list
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pay_style:
            if hasattr(self.pay_style, 'to_alipay_dict'):
                params['pay_style'] = self.pay_style.to_alipay_dict()
            else:
                params['pay_style'] = self.pay_style
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiQualityTestShieldResultSyncModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'check_result_list' in d:
            o.check_result_list = d['check_result_list']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pay_style' in d:
            o.pay_style = d['pay_style']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoCplifeCommunityCreateModel(object):

    def __init__(self):
        self._associated_pois = None
        self._city_code = None
        self._community_address = None
        self._community_locations = None
        self._community_name = None
        self._district_code = None
        self._hotline = None
        self._out_community_id = None
        self._province_code = None

    @property
    def associated_pois(self):
        return self._associated_pois

    @associated_pois.setter
    def associated_pois(self, value):
        if isinstance(value, list):
            self._associated_pois = list()
            for i in value:
                self._associated_pois.append(i)
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def community_address(self):
        return self._community_address

    @community_address.setter
    def community_address(self, value):
        self._community_address = value
    @property
    def community_locations(self):
        return self._community_locations

    @community_locations.setter
    def community_locations(self, value):
        if isinstance(value, list):
            self._community_locations = list()
            for i in value:
                self._community_locations.append(i)
    @property
    def community_name(self):
        return self._community_name

    @community_name.setter
    def community_name(self, value):
        self._community_name = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def hotline(self):
        return self._hotline

    @hotline.setter
    def hotline(self, value):
        self._hotline = value
    @property
    def out_community_id(self):
        return self._out_community_id

    @out_community_id.setter
    def out_community_id(self, value):
        self._out_community_id = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.associated_pois:
            if isinstance(self.associated_pois, list):
                for i in range(0, len(self.associated_pois)):
                    element = self.associated_pois[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.associated_pois[i] = element.to_alipay_dict()
            if hasattr(self.associated_pois, 'to_alipay_dict'):
                params['associated_pois'] = self.associated_pois.to_alipay_dict()
            else:
                params['associated_pois'] = self.associated_pois
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.community_address:
            if hasattr(self.community_address, 'to_alipay_dict'):
                params['community_address'] = self.community_address.to_alipay_dict()
            else:
                params['community_address'] = self.community_address
        if self.community_locations:
            if isinstance(self.community_locations, list):
                for i in range(0, len(self.community_locations)):
                    element = self.community_locations[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.community_locations[i] = element.to_alipay_dict()
            if hasattr(self.community_locations, 'to_alipay_dict'):
                params['community_locations'] = self.community_locations.to_alipay_dict()
            else:
                params['community_locations'] = self.community_locations
        if self.community_name:
            if hasattr(self.community_name, 'to_alipay_dict'):
                params['community_name'] = self.community_name.to_alipay_dict()
            else:
                params['community_name'] = self.community_name
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.hotline:
            if hasattr(self.hotline, 'to_alipay_dict'):
                params['hotline'] = self.hotline.to_alipay_dict()
            else:
                params['hotline'] = self.hotline
        if self.out_community_id:
            if hasattr(self.out_community_id, 'to_alipay_dict'):
                params['out_community_id'] = self.out_community_id.to_alipay_dict()
            else:
                params['out_community_id'] = self.out_community_id
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoCplifeCommunityCreateModel()
        if 'associated_pois' in d:
            o.associated_pois = d['associated_pois']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'community_address' in d:
            o.community_address = d['community_address']
        if 'community_locations' in d:
            o.community_locations = d['community_locations']
        if 'community_name' in d:
            o.community_name = d['community_name']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'hotline' in d:
            o.hotline = d['hotline']
        if 'out_community_id' in d:
            o.out_community_id = d['out_community_id']
        if 'province_code' in d:
            o.province_code = d['province_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankPaymentTradeBankRootQueryModel(object):

    def __init__(self):
        self._bank_name = None

    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeBankRootQueryModel()
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneProductSignQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneProductSignQueryResponse, self).__init__()
        self._agreement_no = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneProductSignQueryResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExerciseItemOpenModelSecond import ExerciseItemOpenModelSecond


class ExerciseItemOpenModel(object):

    def __init__(self):
        self._desc = None
        self._external_item_id = None
        self._item_code = None
        self._item_list = None
        self._name = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def external_item_id(self):
        return self._external_item_id

    @external_item_id.setter
    def external_item_id(self, value):
        self._external_item_id = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def item_list(self):
        return self._item_list

    @item_list.setter
    def item_list(self, value):
        if isinstance(value, ExerciseItemOpenModelSecond):
            self._item_list = value
        else:
            self._item_list = ExerciseItemOpenModelSecond.from_alipay_dict(value)
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.external_item_id:
            if hasattr(self.external_item_id, 'to_alipay_dict'):
                params['external_item_id'] = self.external_item_id.to_alipay_dict()
            else:
                params['external_item_id'] = self.external_item_id
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.item_list:
            if hasattr(self.item_list, 'to_alipay_dict'):
                params['item_list'] = self.item_list.to_alipay_dict()
            else:
                params['item_list'] = self.item_list
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExerciseItemOpenModel()
        if 'desc' in d:
            o.desc = d['desc']
        if 'external_item_id' in d:
            o.external_item_id = d['external_item_id']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'item_list' in d:
            o.item_list = d['item_list']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.WriteOffProcessOrderOpenApiDTO import WriteOffProcessOrderOpenApiDTO


class AlipayBossFncGfsettleprodWriteofforderVerifyModel(object):

    def __init__(self):
        self._write_off_process_order = None

    @property
    def write_off_process_order(self):
        return self._write_off_process_order

    @write_off_process_order.setter
    def write_off_process_order(self, value):
        if isinstance(value, WriteOffProcessOrderOpenApiDTO):
            self._write_off_process_order = value
        else:
            self._write_off_process_order = WriteOffProcessOrderOpenApiDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.write_off_process_order:
            if hasattr(self.write_off_process_order, 'to_alipay_dict'):
                params['write_off_process_order'] = self.write_off_process_order.to_alipay_dict()
            else:
                params['write_off_process_order'] = self.write_off_process_order
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodWriteofforderVerifyModel()
        if 'write_off_process_order' in d:
            o.write_off_process_order = d['write_off_process_order']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InvoiceElementModel import InvoiceElementModel


class AlipayEbppInvoiceTaxnoBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceTaxnoBatchqueryResponse, self).__init__()
        self._invoice_element_list = None
        self._user_id = None

    @property
    def invoice_element_list(self):
        return self._invoice_element_list

    @invoice_element_list.setter
    def invoice_element_list(self, value):
        if isinstance(value, list):
            self._invoice_element_list = list()
            for i in value:
                if isinstance(i, InvoiceElementModel):
                    self._invoice_element_list.append(i)
                else:
                    self._invoice_element_list.append(InvoiceElementModel.from_alipay_dict(i))
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceTaxnoBatchqueryResponse, self).parse_response_content(response_content)
        if 'invoice_element_list' in response:
            self.invoice_element_list = response['invoice_element_list']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoContractMessageSendModel(object):

    def __init__(self):
        self._batch_no = None
        self._cert_no = None
        self._cert_type = None
        self._flow_id = None
        self._isv_app_id = None
        self._msg_template_id = None
        self._sign_platform_code = None
        self._user_ids = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        if isinstance(value, list):
            self._cert_no = list()
            for i in value:
                self._cert_no.append(i)
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def flow_id(self):
        return self._flow_id

    @flow_id.setter
    def flow_id(self, value):
        self._flow_id = value
    @property
    def isv_app_id(self):
        return self._isv_app_id

    @isv_app_id.setter
    def isv_app_id(self, value):
        self._isv_app_id = value
    @property
    def msg_template_id(self):
        return self._msg_template_id

    @msg_template_id.setter
    def msg_template_id(self, value):
        self._msg_template_id = value
    @property
    def sign_platform_code(self):
        return self._sign_platform_code

    @sign_platform_code.setter
    def sign_platform_code(self, value):
        self._sign_platform_code = value
    @property
    def user_ids(self):
        return self._user_ids

    @user_ids.setter
    def user_ids(self, value):
        if isinstance(value, list):
            self._user_ids = list()
            for i in value:
                self._user_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.cert_no:
            if isinstance(self.cert_no, list):
                for i in range(0, len(self.cert_no)):
                    element = self.cert_no[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cert_no[i] = element.to_alipay_dict()
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.flow_id:
            if hasattr(self.flow_id, 'to_alipay_dict'):
                params['flow_id'] = self.flow_id.to_alipay_dict()
            else:
                params['flow_id'] = self.flow_id
        if self.isv_app_id:
            if hasattr(self.isv_app_id, 'to_alipay_dict'):
                params['isv_app_id'] = self.isv_app_id.to_alipay_dict()
            else:
                params['isv_app_id'] = self.isv_app_id
        if self.msg_template_id:
            if hasattr(self.msg_template_id, 'to_alipay_dict'):
                params['msg_template_id'] = self.msg_template_id.to_alipay_dict()
            else:
                params['msg_template_id'] = self.msg_template_id
        if self.sign_platform_code:
            if hasattr(self.sign_platform_code, 'to_alipay_dict'):
                params['sign_platform_code'] = self.sign_platform_code.to_alipay_dict()
            else:
                params['sign_platform_code'] = self.sign_platform_code
        if self.user_ids:
            if isinstance(self.user_ids, list):
                for i in range(0, len(self.user_ids)):
                    element = self.user_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_ids[i] = element.to_alipay_dict()
            if hasattr(self.user_ids, 'to_alipay_dict'):
                params['user_ids'] = self.user_ids.to_alipay_dict()
            else:
                params['user_ids'] = self.user_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoContractMessageSendModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'flow_id' in d:
            o.flow_id = d['flow_id']
        if 'isv_app_id' in d:
            o.isv_app_id = d['isv_app_id']
        if 'msg_template_id' in d:
            o.msg_template_id = d['msg_template_id']
        if 'sign_platform_code' in d:
            o.sign_platform_code = d['sign_platform_code']
        if 'user_ids' in d:
            o.user_ids = d['user_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InputInvoiceOrderRequest import InputInvoiceOrderRequest


class AlipayBossFncGfsettleprodPoinvoicerelateCreateModel(object):

    def __init__(self):
        self._input_invoice_order_request = None

    @property
    def input_invoice_order_request(self):
        return self._input_invoice_order_request

    @input_invoice_order_request.setter
    def input_invoice_order_request(self, value):
        if isinstance(value, InputInvoiceOrderRequest):
            self._input_invoice_order_request = value
        else:
            self._input_invoice_order_request = InputInvoiceOrderRequest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.input_invoice_order_request:
            if hasattr(self.input_invoice_order_request, 'to_alipay_dict'):
                params['input_invoice_order_request'] = self.input_invoice_order_request.to_alipay_dict()
            else:
                params['input_invoice_order_request'] = self.input_invoice_order_request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodPoinvoicerelateCreateModel()
        if 'input_invoice_order_request' in d:
            o.input_invoice_order_request = d['input_invoice_order_request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InfoSecHitDetectItem import InfoSecHitDetectItem


class AlipaySecurityRiskContentAnalyzeResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskContentAnalyzeResponse, self).__init__()
        self._app_scene_data_id = None
        self._event_id = None
        self._hit_detect_items = None
        self._need_query = None
        self._result_action = None
        self._risk_labels = None

    @property
    def app_scene_data_id(self):
        return self._app_scene_data_id

    @app_scene_data_id.setter
    def app_scene_data_id(self, value):
        self._app_scene_data_id = value
    @property
    def event_id(self):
        return self._event_id

    @event_id.setter
    def event_id(self, value):
        self._event_id = value
    @property
    def hit_detect_items(self):
        return self._hit_detect_items

    @hit_detect_items.setter
    def hit_detect_items(self, value):
        if isinstance(value, list):
            self._hit_detect_items = list()
            for i in value:
                if isinstance(i, InfoSecHitDetectItem):
                    self._hit_detect_items.append(i)
                else:
                    self._hit_detect_items.append(InfoSecHitDetectItem.from_alipay_dict(i))
    @property
    def need_query(self):
        return self._need_query

    @need_query.setter
    def need_query(self, value):
        self._need_query = value
    @property
    def result_action(self):
        return self._result_action

    @result_action.setter
    def result_action(self, value):
        self._result_action = value
    @property
    def risk_labels(self):
        return self._risk_labels

    @risk_labels.setter
    def risk_labels(self, value):
        self._risk_labels = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskContentAnalyzeResponse, self).parse_response_content(response_content)
        if 'app_scene_data_id' in response:
            self.app_scene_data_id = response['app_scene_data_id']
        if 'event_id' in response:
            self.event_id = response['event_id']
        if 'hit_detect_items' in response:
            self.hit_detect_items = response['hit_detect_items']
        if 'need_query' in response:
            self.need_query = response['need_query']
        if 'result_action' in response:
            self.result_action = response['result_action']
        if 'risk_labels' in response:
            self.risk_labels = response['risk_labels']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HospitalDTO(object):

    def __init__(self):
        self._hospital_id = None
        self._hospital_name = None
        self._level = None
        self._ownership = None

    @property
    def hospital_id(self):
        return self._hospital_id

    @hospital_id.setter
    def hospital_id(self, value):
        self._hospital_id = value
    @property
    def hospital_name(self):
        return self._hospital_name

    @hospital_name.setter
    def hospital_name(self, value):
        self._hospital_name = value
    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def ownership(self):
        return self._ownership

    @ownership.setter
    def ownership(self, value):
        self._ownership = value


    def to_alipay_dict(self):
        params = dict()
        if self.hospital_id:
            if hasattr(self.hospital_id, 'to_alipay_dict'):
                params['hospital_id'] = self.hospital_id.to_alipay_dict()
            else:
                params['hospital_id'] = self.hospital_id
        if self.hospital_name:
            if hasattr(self.hospital_name, 'to_alipay_dict'):
                params['hospital_name'] = self.hospital_name.to_alipay_dict()
            else:
                params['hospital_name'] = self.hospital_name
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = self.level.to_alipay_dict()
            else:
                params['level'] = self.level
        if self.ownership:
            if hasattr(self.ownership, 'to_alipay_dict'):
                params['ownership'] = self.ownership.to_alipay_dict()
            else:
                params['ownership'] = self.ownership
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HospitalDTO()
        if 'hospital_id' in d:
            o.hospital_id = d['hospital_id']
        if 'hospital_name' in d:
            o.hospital_name = d['hospital_name']
        if 'level' in d:
            o.level = d['level']
        if 'ownership' in d:
            o.ownership = d['ownership']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SelectedMealSideInfo import SelectedMealSideInfo


class SelectedMealInfo(object):

    def __init__(self):
        self._add_price = None
        self._dish_id = None
        self._dish_name = None
        self._ext_infos = None
        self._meal_side_list = None
        self._num = None
        self._out_dish_id = None
        self._out_dish_infos = None
        self._out_sku_id = None
        self._side_price = None
        self._sku_id = None
        self._type = None
        self._unit = None

    @property
    def add_price(self):
        return self._add_price

    @add_price.setter
    def add_price(self, value):
        self._add_price = value
    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_name(self):
        return self._dish_name

    @dish_name.setter
    def dish_name(self, value):
        self._dish_name = value
    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        self._ext_infos = value
    @property
    def meal_side_list(self):
        return self._meal_side_list

    @meal_side_list.setter
    def meal_side_list(self, value):
        if isinstance(value, list):
            self._meal_side_list = list()
            for i in value:
                if isinstance(i, SelectedMealSideInfo):
                    self._meal_side_list.append(i)
                else:
                    self._meal_side_list.append(SelectedMealSideInfo.from_alipay_dict(i))
    @property
    def num(self):
        return self._num

    @num.setter
    def num(self, value):
        self._num = value
    @property
    def out_dish_id(self):
        return self._out_dish_id

    @out_dish_id.setter
    def out_dish_id(self, value):
        self._out_dish_id = value
    @property
    def out_dish_infos(self):
        return self._out_dish_infos

    @out_dish_infos.setter
    def out_dish_infos(self, value):
        self._out_dish_infos = value
    @property
    def out_sku_id(self):
        return self._out_sku_id

    @out_sku_id.setter
    def out_sku_id(self, value):
        self._out_sku_id = value
    @property
    def side_price(self):
        return self._side_price

    @side_price.setter
    def side_price(self, value):
        self._side_price = value
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.add_price:
            if hasattr(self.add_price, 'to_alipay_dict'):
                params['add_price'] = self.add_price.to_alipay_dict()
            else:
                params['add_price'] = self.add_price
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_name:
            if hasattr(self.dish_name, 'to_alipay_dict'):
                params['dish_name'] = self.dish_name.to_alipay_dict()
            else:
                params['dish_name'] = self.dish_name
        if self.ext_infos:
            if hasattr(self.ext_infos, 'to_alipay_dict'):
                params['ext_infos'] = self.ext_infos.to_alipay_dict()
            else:
                params['ext_infos'] = self.ext_infos
        if self.meal_side_list:
            if isinstance(self.meal_side_list, list):
                for i in range(0, len(self.meal_side_list)):
                    element = self.meal_side_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.meal_side_list[i] = element.to_alipay_dict()
            if hasattr(self.meal_side_list, 'to_alipay_dict'):
                params['meal_side_list'] = self.meal_side_list.to_alipay_dict()
            else:
                params['meal_side_list'] = self.meal_side_list
        if self.num:
            if hasattr(self.num, 'to_alipay_dict'):
                params['num'] = self.num.to_alipay_dict()
            else:
                params['num'] = self.num
        if self.out_dish_id:
            if hasattr(self.out_dish_id, 'to_alipay_dict'):
                params['out_dish_id'] = self.out_dish_id.to_alipay_dict()
            else:
                params['out_dish_id'] = self.out_dish_id
        if self.out_dish_infos:
            if hasattr(self.out_dish_infos, 'to_alipay_dict'):
                params['out_dish_infos'] = self.out_dish_infos.to_alipay_dict()
            else:
                params['out_dish_infos'] = self.out_dish_infos
        if self.out_sku_id:
            if hasattr(self.out_sku_id, 'to_alipay_dict'):
                params['out_sku_id'] = self.out_sku_id.to_alipay_dict()
            else:
                params['out_sku_id'] = self.out_sku_id
        if self.side_price:
            if hasattr(self.side_price, 'to_alipay_dict'):
                params['side_price'] = self.side_price.to_alipay_dict()
            else:
                params['side_price'] = self.side_price
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SelectedMealInfo()
        if 'add_price' in d:
            o.add_price = d['add_price']
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_name' in d:
            o.dish_name = d['dish_name']
        if 'ext_infos' in d:
            o.ext_infos = d['ext_infos']
        if 'meal_side_list' in d:
            o.meal_side_list = d['meal_side_list']
        if 'num' in d:
            o.num = d['num']
        if 'out_dish_id' in d:
            o.out_dish_id = d['out_dish_id']
        if 'out_dish_infos' in d:
            o.out_dish_infos = d['out_dish_infos']
        if 'out_sku_id' in d:
            o.out_sku_id = d['out_sku_id']
        if 'side_price' in d:
            o.side_price = d['side_price']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 'type' in d:
            o.type = d['type']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoEduKtSettleinfoQueryModel(object):

    def __init__(self):
        self._bill_date = None
        self._partner_pid = None
        self._school_no = None
        self._smid = None

    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def partner_pid(self):
        return self._partner_pid

    @partner_pid.setter
    def partner_pid(self, value):
        self._partner_pid = value
    @property
    def school_no(self):
        return self._school_no

    @school_no.setter
    def school_no(self, value):
        self._school_no = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = self.bill_date.to_alipay_dict()
            else:
                params['bill_date'] = self.bill_date
        if self.partner_pid:
            if hasattr(self.partner_pid, 'to_alipay_dict'):
                params['partner_pid'] = self.partner_pid.to_alipay_dict()
            else:
                params['partner_pid'] = self.partner_pid
        if self.school_no:
            if hasattr(self.school_no, 'to_alipay_dict'):
                params['school_no'] = self.school_no.to_alipay_dict()
            else:
                params['school_no'] = self.school_no
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoEduKtSettleinfoQueryModel()
        if 'bill_date' in d:
            o.bill_date = d['bill_date']
        if 'partner_pid' in d:
            o.partner_pid = d['partner_pid']
        if 'school_no' in d:
            o.school_no = d['school_no']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditProdarrangementContracttextQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditProdarrangementContracttextQueryResponse, self).__init__()
        self._text = None

    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, value):
        self._text = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditProdarrangementContracttextQueryResponse, self).parse_response_content(response_content)
        if 'text' in response:
            self.text = response['text']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishRuleInfo import KbdishRuleInfo


class KoubeiCateringDishRuleCreateModel(object):

    def __init__(self):
        self._kb_dish_rule_info = None

    @property
    def kb_dish_rule_info(self):
        return self._kb_dish_rule_info

    @kb_dish_rule_info.setter
    def kb_dish_rule_info(self, value):
        if isinstance(value, KbdishRuleInfo):
            self._kb_dish_rule_info = value
        else:
            self._kb_dish_rule_info = KbdishRuleInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.kb_dish_rule_info:
            if hasattr(self.kb_dish_rule_info, 'to_alipay_dict'):
                params['kb_dish_rule_info'] = self.kb_dish_rule_info.to_alipay_dict()
            else:
                params['kb_dish_rule_info'] = self.kb_dish_rule_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishRuleCreateModel()
        if 'kb_dish_rule_info' in d:
            o.kb_dish_rule_info = d['kb_dish_rule_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiTradeTicketUsedRefundModel(object):

    def __init__(self):
        self._request_id = None
        self._ticket_code = None
        self._trans_id = None

    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def ticket_code(self):
        return self._ticket_code

    @ticket_code.setter
    def ticket_code(self, value):
        self._ticket_code = value
    @property
    def trans_id(self):
        return self._trans_id

    @trans_id.setter
    def trans_id(self, value):
        self._trans_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.ticket_code:
            if hasattr(self.ticket_code, 'to_alipay_dict'):
                params['ticket_code'] = self.ticket_code.to_alipay_dict()
            else:
                params['ticket_code'] = self.ticket_code
        if self.trans_id:
            if hasattr(self.trans_id, 'to_alipay_dict'):
                params['trans_id'] = self.trans_id.to_alipay_dict()
            else:
                params['trans_id'] = self.trans_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiTradeTicketUsedRefundModel()
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'ticket_code' in d:
            o.ticket_code = d['ticket_code']
        if 'trans_id' in d:
            o.trans_id = d['trans_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityProdEdgeColorfeedbackCreateModel(object):

    def __init__(self):
        self._biz_param = None
        self._biz_token = None
        self._sec_info = None
        self._tinyapp_id = None
        self._trace_id = None

    @property
    def biz_param(self):
        return self._biz_param

    @biz_param.setter
    def biz_param(self, value):
        self._biz_param = value
    @property
    def biz_token(self):
        return self._biz_token

    @biz_token.setter
    def biz_token(self, value):
        self._biz_token = value
    @property
    def sec_info(self):
        return self._sec_info

    @sec_info.setter
    def sec_info(self, value):
        self._sec_info = value
    @property
    def tinyapp_id(self):
        return self._tinyapp_id

    @tinyapp_id.setter
    def tinyapp_id(self, value):
        self._tinyapp_id = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_param:
            if hasattr(self.biz_param, 'to_alipay_dict'):
                params['biz_param'] = self.biz_param.to_alipay_dict()
            else:
                params['biz_param'] = self.biz_param
        if self.biz_token:
            if hasattr(self.biz_token, 'to_alipay_dict'):
                params['biz_token'] = self.biz_token.to_alipay_dict()
            else:
                params['biz_token'] = self.biz_token
        if self.sec_info:
            if hasattr(self.sec_info, 'to_alipay_dict'):
                params['sec_info'] = self.sec_info.to_alipay_dict()
            else:
                params['sec_info'] = self.sec_info
        if self.tinyapp_id:
            if hasattr(self.tinyapp_id, 'to_alipay_dict'):
                params['tinyapp_id'] = self.tinyapp_id.to_alipay_dict()
            else:
                params['tinyapp_id'] = self.tinyapp_id
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdEdgeColorfeedbackCreateModel()
        if 'biz_param' in d:
            o.biz_param = d['biz_param']
        if 'biz_token' in d:
            o.biz_token = d['biz_token']
        if 'sec_info' in d:
            o.sec_info = d['sec_info']
        if 'tinyapp_id' in d:
            o.tinyapp_id = d['tinyapp_id']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IndividualCustomerInfoVO(object):

    def __init__(self):
        self._cert_no = None
        self._contact_email = None
        self._mobile_phone = None
        self._name = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def mobile_phone(self):
        return self._mobile_phone

    @mobile_phone.setter
    def mobile_phone(self, value):
        self._mobile_phone = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.contact_email:
            if hasattr(self.contact_email, 'to_alipay_dict'):
                params['contact_email'] = self.contact_email.to_alipay_dict()
            else:
                params['contact_email'] = self.contact_email
        if self.mobile_phone:
            if hasattr(self.mobile_phone, 'to_alipay_dict'):
                params['mobile_phone'] = self.mobile_phone.to_alipay_dict()
            else:
                params['mobile_phone'] = self.mobile_phone
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IndividualCustomerInfoVO()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'contact_email' in d:
            o.contact_email = d['contact_email']
        if 'mobile_phone' in d:
            o.mobile_phone = d['mobile_phone']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbAdvertAdvContentResponse import KbAdvertAdvContentResponse
from alipay.aop.api.domain.KbAdvertAdvContent import KbAdvertAdvContent
from alipay.aop.api.domain.KbAdvertSubjectVoucherResponse import KbAdvertSubjectVoucherResponse


class KbAdvertAdvSingleVoucherResponse(object):

    def __init__(self):
        self._adv_content_list = None
        self._content = None
        self._voucher = None

    @property
    def adv_content_list(self):
        return self._adv_content_list

    @adv_content_list.setter
    def adv_content_list(self, value):
        if isinstance(value, list):
            self._adv_content_list = list()
            for i in value:
                if isinstance(i, KbAdvertAdvContentResponse):
                    self._adv_content_list.append(i)
                else:
                    self._adv_content_list.append(KbAdvertAdvContentResponse.from_alipay_dict(i))
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        if isinstance(value, KbAdvertAdvContent):
            self._content = value
        else:
            self._content = KbAdvertAdvContent.from_alipay_dict(value)
    @property
    def voucher(self):
        return self._voucher

    @voucher.setter
    def voucher(self, value):
        if isinstance(value, KbAdvertSubjectVoucherResponse):
            self._voucher = value
        else:
            self._voucher = KbAdvertSubjectVoucherResponse.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.adv_content_list:
            if isinstance(self.adv_content_list, list):
                for i in range(0, len(self.adv_content_list)):
                    element = self.adv_content_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.adv_content_list[i] = element.to_alipay_dict()
            if hasattr(self.adv_content_list, 'to_alipay_dict'):
                params['adv_content_list'] = self.adv_content_list.to_alipay_dict()
            else:
                params['adv_content_list'] = self.adv_content_list
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.voucher:
            if hasattr(self.voucher, 'to_alipay_dict'):
                params['voucher'] = self.voucher.to_alipay_dict()
            else:
                params['voucher'] = self.voucher
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertAdvSingleVoucherResponse()
        if 'adv_content_list' in d:
            o.adv_content_list = d['adv_content_list']
        if 'content' in d:
            o.content = d['content']
        if 'voucher' in d:
            o.voucher = d['voucher']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GiftUserTemplateInfo(object):

    def __init__(self):
        self._template_down_url = None
        self._template_thumb_nail = None
        self._template_up_url = None
        self._valid = None
        self._valid_end_time = None
        self._valid_start_time = None

    @property
    def template_down_url(self):
        return self._template_down_url

    @template_down_url.setter
    def template_down_url(self, value):
        self._template_down_url = value
    @property
    def template_thumb_nail(self):
        return self._template_thumb_nail

    @template_thumb_nail.setter
    def template_thumb_nail(self, value):
        self._template_thumb_nail = value
    @property
    def template_up_url(self):
        return self._template_up_url

    @template_up_url.setter
    def template_up_url(self, value):
        self._template_up_url = value
    @property
    def valid(self):
        return self._valid

    @valid.setter
    def valid(self, value):
        self._valid = value
    @property
    def valid_end_time(self):
        return self._valid_end_time

    @valid_end_time.setter
    def valid_end_time(self, value):
        self._valid_end_time = value
    @property
    def valid_start_time(self):
        return self._valid_start_time

    @valid_start_time.setter
    def valid_start_time(self, value):
        self._valid_start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.template_down_url:
            if hasattr(self.template_down_url, 'to_alipay_dict'):
                params['template_down_url'] = self.template_down_url.to_alipay_dict()
            else:
                params['template_down_url'] = self.template_down_url
        if self.template_thumb_nail:
            if hasattr(self.template_thumb_nail, 'to_alipay_dict'):
                params['template_thumb_nail'] = self.template_thumb_nail.to_alipay_dict()
            else:
                params['template_thumb_nail'] = self.template_thumb_nail
        if self.template_up_url:
            if hasattr(self.template_up_url, 'to_alipay_dict'):
                params['template_up_url'] = self.template_up_url.to_alipay_dict()
            else:
                params['template_up_url'] = self.template_up_url
        if self.valid:
            if hasattr(self.valid, 'to_alipay_dict'):
                params['valid'] = self.valid.to_alipay_dict()
            else:
                params['valid'] = self.valid
        if self.valid_end_time:
            if hasattr(self.valid_end_time, 'to_alipay_dict'):
                params['valid_end_time'] = self.valid_end_time.to_alipay_dict()
            else:
                params['valid_end_time'] = self.valid_end_time
        if self.valid_start_time:
            if hasattr(self.valid_start_time, 'to_alipay_dict'):
                params['valid_start_time'] = self.valid_start_time.to_alipay_dict()
            else:
                params['valid_start_time'] = self.valid_start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GiftUserTemplateInfo()
        if 'template_down_url' in d:
            o.template_down_url = d['template_down_url']
        if 'template_thumb_nail' in d:
            o.template_thumb_nail = d['template_thumb_nail']
        if 'template_up_url' in d:
            o.template_up_url = d['template_up_url']
        if 'valid' in d:
            o.valid = d['valid']
        if 'valid_end_time' in d:
            o.valid_end_time = d['valid_end_time']
        if 'valid_start_time' in d:
            o.valid_start_time = d['valid_start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySocialGiftOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialGiftOrderQueryResponse, self).__init__()
        self._gift_order_status = None
        self._order_status = None
        self._quantity = None
        self._receiver_id = None
        self._sender_id = None
        self._sku_id = None
        self._total_price = None
        self._voucher_id = None

    @property
    def gift_order_status(self):
        return self._gift_order_status

    @gift_order_status.setter
    def gift_order_status(self, value):
        self._gift_order_status = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def receiver_id(self):
        return self._receiver_id

    @receiver_id.setter
    def receiver_id(self, value):
        self._receiver_id = value
    @property
    def sender_id(self):
        return self._sender_id

    @sender_id.setter
    def sender_id(self, value):
        self._sender_id = value
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def total_price(self):
        return self._total_price

    @total_price.setter
    def total_price(self, value):
        self._total_price = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialGiftOrderQueryResponse, self).parse_response_content(response_content)
        if 'gift_order_status' in response:
            self.gift_order_status = response['gift_order_status']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'quantity' in response:
            self.quantity = response['quantity']
        if 'receiver_id' in response:
            self.receiver_id = response['receiver_id']
        if 'sender_id' in response:
            self.sender_id = response['sender_id']
        if 'sku_id' in response:
            self.sku_id = response['sku_id']
        if 'total_price' in response:
            self.total_price = response['total_price']
        if 'voucher_id' in response:
            self.voucher_id = response['voucher_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PromotePageData import PromotePageData


class AlipayDataDataserviceAdPromotepageDownloadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceAdPromotepageDownloadResponse, self).__init__()
        self._conversion_id = None
        self._list = None
        self._page_no = None
        self._page_size = None
        self._total = None

    @property
    def conversion_id(self):
        return self._conversion_id

    @conversion_id.setter
    def conversion_id(self, value):
        self._conversion_id = value
    @property
    def list(self):
        return self._list

    @list.setter
    def list(self, value):
        if isinstance(value, list):
            self._list = list()
            for i in value:
                if isinstance(i, PromotePageData):
                    self._list.append(i)
                else:
                    self._list.append(PromotePageData.from_alipay_dict(i))
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceAdPromotepageDownloadResponse, self).parse_response_content(response_content)
        if 'conversion_id' in response:
            self.conversion_id = response['conversion_id']
        if 'list' in response:
            self.list = response['list']
        if 'page_no' in response:
            self.page_no = response['page_no']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total' in response:
            self.total = response['total']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HealthCard(object):

    def __init__(self):
        self._birthday = None
        self._cert_no = None
        self._health_card_no = None
        self._name = None
        self._sex = None

    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def health_card_no(self):
        return self._health_card_no

    @health_card_no.setter
    def health_card_no(self, value):
        self._health_card_no = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def sex(self):
        return self._sex

    @sex.setter
    def sex(self, value):
        self._sex = value


    def to_alipay_dict(self):
        params = dict()
        if self.birthday:
            if hasattr(self.birthday, 'to_alipay_dict'):
                params['birthday'] = self.birthday.to_alipay_dict()
            else:
                params['birthday'] = self.birthday
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.health_card_no:
            if hasattr(self.health_card_no, 'to_alipay_dict'):
                params['health_card_no'] = self.health_card_no.to_alipay_dict()
            else:
                params['health_card_no'] = self.health_card_no
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.sex:
            if hasattr(self.sex, 'to_alipay_dict'):
                params['sex'] = self.sex.to_alipay_dict()
            else:
                params['sex'] = self.sex
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HealthCard()
        if 'birthday' in d:
            o.birthday = d['birthday']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'health_card_no' in d:
            o.health_card_no = d['health_card_no']
        if 'name' in d:
            o.name = d['name']
        if 'sex' in d:
            o.sex = d['sex']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.QueryComplexLabelRule import QueryComplexLabelRule


class QueryGroup(object):

    def __init__(self):
        self._count = None
        self._id = None
        self._label_rule = None
        self._name = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def label_rule(self):
        return self._label_rule

    @label_rule.setter
    def label_rule(self, value):
        if isinstance(value, list):
            self._label_rule = list()
            for i in value:
                if isinstance(i, QueryComplexLabelRule):
                    self._label_rule.append(i)
                else:
                    self._label_rule.append(QueryComplexLabelRule.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.label_rule:
            if isinstance(self.label_rule, list):
                for i in range(0, len(self.label_rule)):
                    element = self.label_rule[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.label_rule[i] = element.to_alipay_dict()
            if hasattr(self.label_rule, 'to_alipay_dict'):
                params['label_rule'] = self.label_rule.to_alipay_dict()
            else:
                params['label_rule'] = self.label_rule
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueryGroup()
        if 'count' in d:
            o.count = d['count']
        if 'id' in d:
            o.id = d['id']
        if 'label_rule' in d:
            o.label_rule = d['label_rule']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainTwcUserinfoMatchModel(object):

    def __init__(self):
        self._alipay_user_id = None
        self._call_no_hash = None
        self._unify_no = None
        self._unify_no_hash = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def call_no_hash(self):
        return self._call_no_hash

    @call_no_hash.setter
    def call_no_hash(self, value):
        self._call_no_hash = value
    @property
    def unify_no(self):
        return self._unify_no

    @unify_no.setter
    def unify_no(self, value):
        self._unify_no = value
    @property
    def unify_no_hash(self):
        return self._unify_no_hash

    @unify_no_hash.setter
    def unify_no_hash(self, value):
        self._unify_no_hash = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.call_no_hash:
            if hasattr(self.call_no_hash, 'to_alipay_dict'):
                params['call_no_hash'] = self.call_no_hash.to_alipay_dict()
            else:
                params['call_no_hash'] = self.call_no_hash
        if self.unify_no:
            if hasattr(self.unify_no, 'to_alipay_dict'):
                params['unify_no'] = self.unify_no.to_alipay_dict()
            else:
                params['unify_no'] = self.unify_no
        if self.unify_no_hash:
            if hasattr(self.unify_no_hash, 'to_alipay_dict'):
                params['unify_no_hash'] = self.unify_no_hash.to_alipay_dict()
            else:
                params['unify_no_hash'] = self.unify_no_hash
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainTwcUserinfoMatchModel()
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'call_no_hash' in d:
            o.call_no_hash = d['call_no_hash']
        if 'unify_no' in d:
            o.unify_no = d['unify_no']
        if 'unify_no_hash' in d:
            o.unify_no_hash = d['unify_no_hash']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMapGeocodingReverseModel(object):

    def __init__(self):
        self._channel = None
        self._latitude = None
        self._longitude = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMapGeocodingReverseModel()
        if 'channel' in d:
            o.channel = d['channel']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceCompanyQueryModel(object):

    def __init__(self):
        self._payee_register_no = None
        self._register_id = None

    @property
    def payee_register_no(self):
        return self._payee_register_no

    @payee_register_no.setter
    def payee_register_no(self, value):
        self._payee_register_no = value
    @property
    def register_id(self):
        return self._register_id

    @register_id.setter
    def register_id(self, value):
        self._register_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.payee_register_no:
            if hasattr(self.payee_register_no, 'to_alipay_dict'):
                params['payee_register_no'] = self.payee_register_no.to_alipay_dict()
            else:
                params['payee_register_no'] = self.payee_register_no
        if self.register_id:
            if hasattr(self.register_id, 'to_alipay_dict'):
                params['register_id'] = self.register_id.to_alipay_dict()
            else:
                params['register_id'] = self.register_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceCompanyQueryModel()
        if 'payee_register_no' in d:
            o.payee_register_no = d['payee_register_no']
        if 'register_id' in d:
            o.register_id = d['register_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HotelGuests(object):

    def __init__(self):
        self._guest_name = None
        self._member_level = None
        self._telephone = None

    @property
    def guest_name(self):
        return self._guest_name

    @guest_name.setter
    def guest_name(self, value):
        self._guest_name = value
    @property
    def member_level(self):
        return self._member_level

    @member_level.setter
    def member_level(self, value):
        self._member_level = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value


    def to_alipay_dict(self):
        params = dict()
        if self.guest_name:
            if hasattr(self.guest_name, 'to_alipay_dict'):
                params['guest_name'] = self.guest_name.to_alipay_dict()
            else:
                params['guest_name'] = self.guest_name
        if self.member_level:
            if hasattr(self.member_level, 'to_alipay_dict'):
                params['member_level'] = self.member_level.to_alipay_dict()
            else:
                params['member_level'] = self.member_level
        if self.telephone:
            if hasattr(self.telephone, 'to_alipay_dict'):
                params['telephone'] = self.telephone.to_alipay_dict()
            else:
                params['telephone'] = self.telephone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HotelGuests()
        if 'guest_name' in d:
            o.guest_name = d['guest_name']
        if 'member_level' in d:
            o.member_level = d['member_level']
        if 'telephone' in d:
            o.telephone = d['telephone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CardAmountDetailVO(object):

    def __init__(self):
        self._amount = None
        self._card_holder_name = None
        self._out_bank_card_no = None
        self._out_bank_inst_id = None
        self._out_bank_name = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def card_holder_name(self):
        return self._card_holder_name

    @card_holder_name.setter
    def card_holder_name(self, value):
        self._card_holder_name = value
    @property
    def out_bank_card_no(self):
        return self._out_bank_card_no

    @out_bank_card_no.setter
    def out_bank_card_no(self, value):
        self._out_bank_card_no = value
    @property
    def out_bank_inst_id(self):
        return self._out_bank_inst_id

    @out_bank_inst_id.setter
    def out_bank_inst_id(self, value):
        self._out_bank_inst_id = value
    @property
    def out_bank_name(self):
        return self._out_bank_name

    @out_bank_name.setter
    def out_bank_name(self, value):
        self._out_bank_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.card_holder_name:
            if hasattr(self.card_holder_name, 'to_alipay_dict'):
                params['card_holder_name'] = self.card_holder_name.to_alipay_dict()
            else:
                params['card_holder_name'] = self.card_holder_name
        if self.out_bank_card_no:
            if hasattr(self.out_bank_card_no, 'to_alipay_dict'):
                params['out_bank_card_no'] = self.out_bank_card_no.to_alipay_dict()
            else:
                params['out_bank_card_no'] = self.out_bank_card_no
        if self.out_bank_inst_id:
            if hasattr(self.out_bank_inst_id, 'to_alipay_dict'):
                params['out_bank_inst_id'] = self.out_bank_inst_id.to_alipay_dict()
            else:
                params['out_bank_inst_id'] = self.out_bank_inst_id
        if self.out_bank_name:
            if hasattr(self.out_bank_name, 'to_alipay_dict'):
                params['out_bank_name'] = self.out_bank_name.to_alipay_dict()
            else:
                params['out_bank_name'] = self.out_bank_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CardAmountDetailVO()
        if 'amount' in d:
            o.amount = d['amount']
        if 'card_holder_name' in d:
            o.card_holder_name = d['card_holder_name']
        if 'out_bank_card_no' in d:
            o.out_bank_card_no = d['out_bank_card_no']
        if 'out_bank_inst_id' in d:
            o.out_bank_inst_id = d['out_bank_inst_id']
        if 'out_bank_name' in d:
            o.out_bank_name = d['out_bank_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiServindustryShopLicenseQueryModel(object):

    def __init__(self):
        self._partner_id = None

    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiServindustryShopLicenseQueryModel()
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RightNoOpenedList import RightNoOpenedList


class AlipayInsMarketingGiftQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsMarketingGiftQueryResponse, self).__init__()
        self._channel = None
        self._gift_prod_code = None
        self._opened = None
        self._right_no_opened_list = None
        self._user_id = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def gift_prod_code(self):
        return self._gift_prod_code

    @gift_prod_code.setter
    def gift_prod_code(self, value):
        self._gift_prod_code = value
    @property
    def opened(self):
        return self._opened

    @opened.setter
    def opened(self, value):
        self._opened = value
    @property
    def right_no_opened_list(self):
        return self._right_no_opened_list

    @right_no_opened_list.setter
    def right_no_opened_list(self, value):
        if isinstance(value, list):
            self._right_no_opened_list = list()
            for i in value:
                if isinstance(i, RightNoOpenedList):
                    self._right_no_opened_list.append(i)
                else:
                    self._right_no_opened_list.append(RightNoOpenedList.from_alipay_dict(i))
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsMarketingGiftQueryResponse, self).parse_response_content(response_content)
        if 'channel' in response:
            self.channel = response['channel']
        if 'gift_prod_code' in response:
            self.gift_prod_code = response['gift_prod_code']
        if 'opened' in response:
            self.opened = response['opened']
        if 'right_no_opened_list' in response:
            self.right_no_opened_list = response['right_no_opened_list']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceDataCampaignSendModel(object):

    def __init__(self):
        self._camp_category = None
        self._camp_channel = None
        self._camp_id = None
        self._camp_time = None
        self._cross_cycle = None
        self._cur_num = None
        self._ext_info = None
        self._notify_type = None
        self._serial_no = None
        self._total_num = None
        self._trade_no = None
        self._user_id = None

    @property
    def camp_category(self):
        return self._camp_category

    @camp_category.setter
    def camp_category(self, value):
        self._camp_category = value
    @property
    def camp_channel(self):
        return self._camp_channel

    @camp_channel.setter
    def camp_channel(self, value):
        self._camp_channel = value
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def camp_time(self):
        return self._camp_time

    @camp_time.setter
    def camp_time(self, value):
        self._camp_time = value
    @property
    def cross_cycle(self):
        return self._cross_cycle

    @cross_cycle.setter
    def cross_cycle(self, value):
        self._cross_cycle = value
    @property
    def cur_num(self):
        return self._cur_num

    @cur_num.setter
    def cur_num(self, value):
        self._cur_num = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def notify_type(self):
        return self._notify_type

    @notify_type.setter
    def notify_type(self, value):
        self._notify_type = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value
    @property
    def total_num(self):
        return self._total_num

    @total_num.setter
    def total_num(self, value):
        self._total_num = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.camp_category:
            if hasattr(self.camp_category, 'to_alipay_dict'):
                params['camp_category'] = self.camp_category.to_alipay_dict()
            else:
                params['camp_category'] = self.camp_category
        if self.camp_channel:
            if hasattr(self.camp_channel, 'to_alipay_dict'):
                params['camp_channel'] = self.camp_channel.to_alipay_dict()
            else:
                params['camp_channel'] = self.camp_channel
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.camp_time:
            if hasattr(self.camp_time, 'to_alipay_dict'):
                params['camp_time'] = self.camp_time.to_alipay_dict()
            else:
                params['camp_time'] = self.camp_time
        if self.cross_cycle:
            if hasattr(self.cross_cycle, 'to_alipay_dict'):
                params['cross_cycle'] = self.cross_cycle.to_alipay_dict()
            else:
                params['cross_cycle'] = self.cross_cycle
        if self.cur_num:
            if hasattr(self.cur_num, 'to_alipay_dict'):
                params['cur_num'] = self.cur_num.to_alipay_dict()
            else:
                params['cur_num'] = self.cur_num
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.notify_type:
            if hasattr(self.notify_type, 'to_alipay_dict'):
                params['notify_type'] = self.notify_type.to_alipay_dict()
            else:
                params['notify_type'] = self.notify_type
        if self.serial_no:
            if hasattr(self.serial_no, 'to_alipay_dict'):
                params['serial_no'] = self.serial_no.to_alipay_dict()
            else:
                params['serial_no'] = self.serial_no
        if self.total_num:
            if hasattr(self.total_num, 'to_alipay_dict'):
                params['total_num'] = self.total_num.to_alipay_dict()
            else:
                params['total_num'] = self.total_num
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceDataCampaignSendModel()
        if 'camp_category' in d:
            o.camp_category = d['camp_category']
        if 'camp_channel' in d:
            o.camp_channel = d['camp_channel']
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'camp_time' in d:
            o.camp_time = d['camp_time']
        if 'cross_cycle' in d:
            o.cross_cycle = d['cross_cycle']
        if 'cur_num' in d:
            o.cur_num = d['cur_num']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'notify_type' in d:
            o.notify_type = d['notify_type']
        if 'serial_no' in d:
            o.serial_no = d['serial_no']
        if 'total_num' in d:
            o.total_num = d['total_num']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMdataTagGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMdataTagGetResponse, self).__init__()
        self._tag_values = None

    @property
    def tag_values(self):
        return self._tag_values

    @tag_values.setter
    def tag_values(self, value):
        self._tag_values = value

    def parse_response_content(self, response_content):
        response = super(AlipayMdataTagGetResponse, self).parse_response_content(response_content)
        if 'tag_values' in response:
            self.tag_values = response['tag_values']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PointTransInfo import PointTransInfo


class AntfortuneEquityInstpointTransQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneEquityInstpointTransQueryResponse, self).__init__()
        self._trans_info = None

    @property
    def trans_info(self):
        return self._trans_info

    @trans_info.setter
    def trans_info(self, value):
        if isinstance(value, list):
            self._trans_info = list()
            for i in value:
                if isinstance(i, PointTransInfo):
                    self._trans_info.append(i)
                else:
                    self._trans_info.append(PointTransInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntfortuneEquityInstpointTransQueryResponse, self).parse_response_content(response_content)
        if 'trans_info' in response:
            self.trans_info = response['trans_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserInvitetaskExchangeConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserInvitetaskExchangeConsultResponse, self).__init__()
        self._consult_result = None

    @property
    def consult_result(self):
        return self._consult_result

    @consult_result.setter
    def consult_result(self, value):
        self._consult_result = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserInvitetaskExchangeConsultResponse, self).parse_response_content(response_content)
        if 'consult_result' in response:
            self.consult_result = response['consult_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditLoanapplyApplyCreateResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoanapplyApplyCreateResponse, self).__init__()
        self._apply_no = None
        self._ip_role_id = None
        self._sub_apply_no = None

    @property
    def apply_no(self):
        return self._apply_no

    @apply_no.setter
    def apply_no(self, value):
        self._apply_no = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def sub_apply_no(self):
        return self._sub_apply_no

    @sub_apply_no.setter
    def sub_apply_no(self, value):
        self._sub_apply_no = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoanapplyApplyCreateResponse, self).parse_response_content(response_content)
        if 'apply_no' in response:
            self.apply_no = response['apply_no']
        if 'ip_role_id' in response:
            self.ip_role_id = response['ip_role_id']
        if 'sub_apply_no' in response:
            self.sub_apply_no = response['sub_apply_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TimeCardSimpleItemInfo import TimeCardSimpleItemInfo


class TimeCardUseLogRecordInfo(object):

    def __init__(self):
        self._amount = None
        self._card_id = None
        self._log_id = None
        self._log_time = None
        self._log_type = None
        self._time_card_info = None
        self._user_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def card_id(self):
        return self._card_id

    @card_id.setter
    def card_id(self, value):
        self._card_id = value
    @property
    def log_id(self):
        return self._log_id

    @log_id.setter
    def log_id(self, value):
        self._log_id = value
    @property
    def log_time(self):
        return self._log_time

    @log_time.setter
    def log_time(self, value):
        self._log_time = value
    @property
    def log_type(self):
        return self._log_type

    @log_type.setter
    def log_type(self, value):
        self._log_type = value
    @property
    def time_card_info(self):
        return self._time_card_info

    @time_card_info.setter
    def time_card_info(self, value):
        if isinstance(value, TimeCardSimpleItemInfo):
            self._time_card_info = value
        else:
            self._time_card_info = TimeCardSimpleItemInfo.from_alipay_dict(value)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.card_id:
            if hasattr(self.card_id, 'to_alipay_dict'):
                params['card_id'] = self.card_id.to_alipay_dict()
            else:
                params['card_id'] = self.card_id
        if self.log_id:
            if hasattr(self.log_id, 'to_alipay_dict'):
                params['log_id'] = self.log_id.to_alipay_dict()
            else:
                params['log_id'] = self.log_id
        if self.log_time:
            if hasattr(self.log_time, 'to_alipay_dict'):
                params['log_time'] = self.log_time.to_alipay_dict()
            else:
                params['log_time'] = self.log_time
        if self.log_type:
            if hasattr(self.log_type, 'to_alipay_dict'):
                params['log_type'] = self.log_type.to_alipay_dict()
            else:
                params['log_type'] = self.log_type
        if self.time_card_info:
            if hasattr(self.time_card_info, 'to_alipay_dict'):
                params['time_card_info'] = self.time_card_info.to_alipay_dict()
            else:
                params['time_card_info'] = self.time_card_info
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TimeCardUseLogRecordInfo()
        if 'amount' in d:
            o.amount = d['amount']
        if 'card_id' in d:
            o.card_id = d['card_id']
        if 'log_id' in d:
            o.log_id = d['log_id']
        if 'log_time' in d:
            o.log_time = d['log_time']
        if 'log_type' in d:
            o.log_type = d['log_type']
        if 'time_card_info' in d:
            o.time_card_info = d['time_card_info']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCognitiveOcrImageclassifyQueryModel(object):

    def __init__(self):
        self._image_content = None

    @property
    def image_content(self):
        return self._image_content

    @image_content.setter
    def image_content(self, value):
        self._image_content = value


    def to_alipay_dict(self):
        params = dict()
        if self.image_content:
            if hasattr(self.image_content, 'to_alipay_dict'):
                params['image_content'] = self.image_content.to_alipay_dict()
            else:
                params['image_content'] = self.image_content
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCognitiveOcrImageclassifyQueryModel()
        if 'image_content' in d:
            o.image_content = d['image_content']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CompanyOverviewHighLight import CompanyOverviewHighLight


class CompanyOverviewLineInfo(object):

    def __init__(self):
        self._content = None
        self._high_light_model_list = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def high_light_model_list(self):
        return self._high_light_model_list

    @high_light_model_list.setter
    def high_light_model_list(self, value):
        if isinstance(value, list):
            self._high_light_model_list = list()
            for i in value:
                if isinstance(i, CompanyOverviewHighLight):
                    self._high_light_model_list.append(i)
                else:
                    self._high_light_model_list.append(CompanyOverviewHighLight.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.high_light_model_list:
            if isinstance(self.high_light_model_list, list):
                for i in range(0, len(self.high_light_model_list)):
                    element = self.high_light_model_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.high_light_model_list[i] = element.to_alipay_dict()
            if hasattr(self.high_light_model_list, 'to_alipay_dict'):
                params['high_light_model_list'] = self.high_light_model_list.to_alipay_dict()
            else:
                params['high_light_model_list'] = self.high_light_model_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CompanyOverviewLineInfo()
        if 'content' in d:
            o.content = d['content']
        if 'high_light_model_list' in d:
            o.high_light_model_list = d['high_light_model_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SpAccountInfo import SpAccountInfo


class AlipayFinancialnetAuthSpaccountQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFinancialnetAuthSpaccountQueryResponse, self).__init__()
        self._account_info = None
        self._error_code = None
        self._error_message = None
        self._is_success = None

    @property
    def account_info(self):
        return self._account_info

    @account_info.setter
    def account_info(self, value):
        if isinstance(value, list):
            self._account_info = list()
            for i in value:
                if isinstance(i, SpAccountInfo):
                    self._account_info.append(i)
                else:
                    self._account_info.append(SpAccountInfo.from_alipay_dict(i))
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def is_success(self):
        return self._is_success

    @is_success.setter
    def is_success(self, value):
        self._is_success = value

    def parse_response_content(self, response_content):
        response = super(AlipayFinancialnetAuthSpaccountQueryResponse, self).parse_response_content(response_content)
        if 'account_info' in response:
            self.account_info = response['account_info']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'is_success' in response:
            self.is_success = response['is_success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.GroupFundUserBill import GroupFundUserBill


class AlipayFundTransGroupfundsUserbillsQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransGroupfundsUserbillsQueryResponse, self).__init__()
        self._user_bills = None

    @property
    def user_bills(self):
        return self._user_bills

    @user_bills.setter
    def user_bills(self, value):
        if isinstance(value, GroupFundUserBill):
            self._user_bills = value
        else:
            self._user_bills = GroupFundUserBill.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransGroupfundsUserbillsQueryResponse, self).parse_response_content(response_content)
        if 'user_bills' in response:
            self.user_bills = response['user_bills']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppServiceValidpageQueryModel(object):

    def __init__(self):
        self._current_page = None
        self._page_size = None
        self._region_codes = None
        self._scene_code = None
        self._service_name = None

    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def region_codes(self):
        return self._region_codes

    @region_codes.setter
    def region_codes(self, value):
        if isinstance(value, list):
            self._region_codes = list()
            for i in value:
                self._region_codes.append(i)
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.current_page:
            if hasattr(self.current_page, 'to_alipay_dict'):
                params['current_page'] = self.current_page.to_alipay_dict()
            else:
                params['current_page'] = self.current_page
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.region_codes:
            if isinstance(self.region_codes, list):
                for i in range(0, len(self.region_codes)):
                    element = self.region_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.region_codes[i] = element.to_alipay_dict()
            if hasattr(self.region_codes, 'to_alipay_dict'):
                params['region_codes'] = self.region_codes.to_alipay_dict()
            else:
                params['region_codes'] = self.region_codes
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppServiceValidpageQueryModel()
        if 'current_page' in d:
            o.current_page = d['current_page']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'region_codes' in d:
            o.region_codes = d['region_codes']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'service_name' in d:
            o.service_name = d['service_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccountLogItemResult(object):

    def __init__(self):
        self._account_log_id = None
        self._alipay_order_no = None
        self._balance = None
        self._bill_source = None
        self._biz_desc = None
        self._biz_nos = None
        self._biz_orig_no = None
        self._complement_info = None
        self._direction = None
        self._merchant_order_no = None
        self._merchant_out_refund_no = None
        self._other_account = None
        self._store_name = None
        self._trans_amount = None
        self._trans_dt = None
        self._trans_memo = None
        self._type = None

    @property
    def account_log_id(self):
        return self._account_log_id

    @account_log_id.setter
    def account_log_id(self, value):
        self._account_log_id = value
    @property
    def alipay_order_no(self):
        return self._alipay_order_no

    @alipay_order_no.setter
    def alipay_order_no(self, value):
        self._alipay_order_no = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def bill_source(self):
        return self._bill_source

    @bill_source.setter
    def bill_source(self, value):
        self._bill_source = value
    @property
    def biz_desc(self):
        return self._biz_desc

    @biz_desc.setter
    def biz_desc(self, value):
        self._biz_desc = value
    @property
    def biz_nos(self):
        return self._biz_nos

    @biz_nos.setter
    def biz_nos(self, value):
        self._biz_nos = value
    @property
    def biz_orig_no(self):
        return self._biz_orig_no

    @biz_orig_no.setter
    def biz_orig_no(self, value):
        self._biz_orig_no = value
    @property
    def complement_info(self):
        return self._complement_info

    @complement_info.setter
    def complement_info(self, value):
        self._complement_info = value
    @property
    def direction(self):
        return self._direction

    @direction.setter
    def direction(self, value):
        self._direction = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def merchant_out_refund_no(self):
        return self._merchant_out_refund_no

    @merchant_out_refund_no.setter
    def merchant_out_refund_no(self, value):
        self._merchant_out_refund_no = value
    @property
    def other_account(self):
        return self._other_account

    @other_account.setter
    def other_account(self, value):
        self._other_account = value
    @property
    def store_name(self):
        return self._store_name

    @store_name.setter
    def store_name(self, value):
        self._store_name = value
    @property
    def trans_amount(self):
        return self._trans_amount

    @trans_amount.setter
    def trans_amount(self, value):
        self._trans_amount = value
    @property
    def trans_dt(self):
        return self._trans_dt

    @trans_dt.setter
    def trans_dt(self, value):
        self._trans_dt = value
    @property
    def trans_memo(self):
        return self._trans_memo

    @trans_memo.setter
    def trans_memo(self, value):
        self._trans_memo = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_log_id:
            if hasattr(self.account_log_id, 'to_alipay_dict'):
                params['account_log_id'] = self.account_log_id.to_alipay_dict()
            else:
                params['account_log_id'] = self.account_log_id
        if self.alipay_order_no:
            if hasattr(self.alipay_order_no, 'to_alipay_dict'):
                params['alipay_order_no'] = self.alipay_order_no.to_alipay_dict()
            else:
                params['alipay_order_no'] = self.alipay_order_no
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.bill_source:
            if hasattr(self.bill_source, 'to_alipay_dict'):
                params['bill_source'] = self.bill_source.to_alipay_dict()
            else:
                params['bill_source'] = self.bill_source
        if self.biz_desc:
            if hasattr(self.biz_desc, 'to_alipay_dict'):
                params['biz_desc'] = self.biz_desc.to_alipay_dict()
            else:
                params['biz_desc'] = self.biz_desc
        if self.biz_nos:
            if hasattr(self.biz_nos, 'to_alipay_dict'):
                params['biz_nos'] = self.biz_nos.to_alipay_dict()
            else:
                params['biz_nos'] = self.biz_nos
        if self.biz_orig_no:
            if hasattr(self.biz_orig_no, 'to_alipay_dict'):
                params['biz_orig_no'] = self.biz_orig_no.to_alipay_dict()
            else:
                params['biz_orig_no'] = self.biz_orig_no
        if self.complement_info:
            if hasattr(self.complement_info, 'to_alipay_dict'):
                params['complement_info'] = self.complement_info.to_alipay_dict()
            else:
                params['complement_info'] = self.complement_info
        if self.direction:
            if hasattr(self.direction, 'to_alipay_dict'):
                params['direction'] = self.direction.to_alipay_dict()
            else:
                params['direction'] = self.direction
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.merchant_out_refund_no:
            if hasattr(self.merchant_out_refund_no, 'to_alipay_dict'):
                params['merchant_out_refund_no'] = self.merchant_out_refund_no.to_alipay_dict()
            else:
                params['merchant_out_refund_no'] = self.merchant_out_refund_no
        if self.other_account:
            if hasattr(self.other_account, 'to_alipay_dict'):
                params['other_account'] = self.other_account.to_alipay_dict()
            else:
                params['other_account'] = self.other_account
        if self.store_name:
            if hasattr(self.store_name, 'to_alipay_dict'):
                params['store_name'] = self.store_name.to_alipay_dict()
            else:
                params['store_name'] = self.store_name
        if self.trans_amount:
            if hasattr(self.trans_amount, 'to_alipay_dict'):
                params['trans_amount'] = self.trans_amount.to_alipay_dict()
            else:
                params['trans_amount'] = self.trans_amount
        if self.trans_dt:
            if hasattr(self.trans_dt, 'to_alipay_dict'):
                params['trans_dt'] = self.trans_dt.to_alipay_dict()
            else:
                params['trans_dt'] = self.trans_dt
        if self.trans_memo:
            if hasattr(self.trans_memo, 'to_alipay_dict'):
                params['trans_memo'] = self.trans_memo.to_alipay_dict()
            else:
                params['trans_memo'] = self.trans_memo
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccountLogItemResult()
        if 'account_log_id' in d:
            o.account_log_id = d['account_log_id']
        if 'alipay_order_no' in d:
            o.alipay_order_no = d['alipay_order_no']
        if 'balance' in d:
            o.balance = d['balance']
        if 'bill_source' in d:
            o.bill_source = d['bill_source']
        if 'biz_desc' in d:
            o.biz_desc = d['biz_desc']
        if 'biz_nos' in d:
            o.biz_nos = d['biz_nos']
        if 'biz_orig_no' in d:
            o.biz_orig_no = d['biz_orig_no']
        if 'complement_info' in d:
            o.complement_info = d['complement_info']
        if 'direction' in d:
            o.direction = d['direction']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'merchant_out_refund_no' in d:
            o.merchant_out_refund_no = d['merchant_out_refund_no']
        if 'other_account' in d:
            o.other_account = d['other_account']
        if 'store_name' in d:
            o.store_name = d['store_name']
        if 'trans_amount' in d:
            o.trans_amount = d['trans_amount']
        if 'trans_dt' in d:
            o.trans_dt = d['trans_dt']
        if 'trans_memo' in d:
            o.trans_memo = d['trans_memo']
        if 'type' in d:
            o.type = d['type']
        return o


